pub struct Subscription {
pub kind: SubscriptionKind,
pub topic: String,
pub instructions: Vec<Instruction>,
pub subscriber: String,
pub event_account: Option<String>,
pub timestamp_range: Option<(u64, u64)>,
}Expand description
Subscription returned by Rialo RPC to describe a Subscription object stored by a user for
a given topic.
Fields
kind: SubscriptionKindSubscription kind.
topic: StringTopic.
instructions: Vec<Instruction>Instructions to be executed.
subscriber: StringSubscriber pubkey in base58.
event_account: Option<String>The account pubkey in base58 that stores the event data. Used when the subscription precisely targets a specific event account.
timestamp_range: Option<(u64, u64)>The timestamp range to trigger the transaction, if provided. Left boundary is inclusive, right boundary is exclusive.